==> api-service-common-0.12.28.tgz: package/src/middleware/api_config.ts <==
/*************************************************************************
 *
 * Troven CONFIDENTIAL
 * __________________
 *
 *  (c) 2017-2020 Troven Pty Ltd
 *  All Rights Reserved.
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of Troven Pty Ltd and its licensors,
 * if any.  The intellectual and technical concepts contained
 * herein are proprietary to Troven Pty Ltd
 * and its suppliers and may be covered by International and Regional Patents,
 * patents in process, and are protected by trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Troven Pty Ltd.
 */

import * as assert from "assert";
import { IOperation, IChassisContext, IChassisFeature, Vars } from "api-service-core";
import * as _ from "lodash";

/**
 * Inline Configuration
 * -------------
 * Attach an API resource to serve 'feature.config'
 *
 *
 * @type {{name: string, title: string, description: string, fn: module.exports.fn}}
 */
export default class api_config implements IChassisFeature {
    name = "api.config";
    title = "Config API";

    fn(operation: IOperation, options: any): Function {
        let context: IChassisContext = operation.context;
        assert(context, "missing context");

        return function (_req, res: any) {

            let remote_config = _.extend({}, context.config.remote_config, options.config);
            // console.log("api.config [remote_config]: %o", remote_config);
    
            // parse external @ files
            remote_config = Vars.resolve_externals(remote_config);
    
            // interpolate variables
            remote_config = Vars.resolve(remote_config, context.config);

            res.status(200);
            res.send( remote_config );
        }
    }

};

==> api-service-common-0.16.13.tgz: package/src/middleware/api_config.ts <==
/*************************************************************************
 *
 * Troven CONFIDENTIAL
 * __________________
 *
 *  (c) 2017-2020 Troven Pty Ltd
 *  All Rights Reserved.
 *
 * NOTICE:  All information contained herein is, and remains
 * the property of Troven Pty Ltd and its licensors,
 * if any.  The intellectual and technical concepts contained
 * herein are proprietary to Troven Pty Ltd
 * and its suppliers and may be covered by International and Regional Patents,
 * patents in process, and are protected by trade secret or copyright law.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Troven Pty Ltd.
 */

import * as assert from "assert";
import { IOperation, IChassisContext, IChassisFeature, Vars } from "api-service-core";
import * as _ from "lodash";

/**
 * Inline Configuration
 * -------------
 * Attach an API resource to serve 'feature.config'
 *
 *
 * @type {{name: string, title: string, description: string, fn: module.exports.fn}}
 */
export default class api_config implements IChassisFeature {
    name = "api.config";
    title = "Config API";

    fn(operation: IOperation, options: any): Function {
        let context: IChassisContext = operation.context;
        assert(context, "missing context");

        return function (_req, res: any) {

            let remote_config = _.extend({}, context.config.remote_config, options.config);
            // console.log("api.config [remote_config]: %j", remote_config);
    
            // parse external @ files
            remote_config = Vars.resolve_externals(remote_config);
    
            // interpolate variables
            remote_config = Vars.resolve(remote_config, context.config);

            res.status(200);
            res.send( remote_config );
        }
    }

};
